==> polyglot_2.7.0.201508251639.jar: src/polyglot/ast/NullLit_c.java <==
/*******************************************************************************
 * This file is part of the Polyglot extensible compiler framework.
 *
 * Copyright (c) 2000-2012 Polyglot project group, Cornell University
 * Copyright (c) 2006-2012 IBM Corporation
 * All rights reserved.
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This program and the accompanying materials are made available under
 * the terms of the Lesser GNU Public License v2.0 which accompanies this
 * distribution.
 * 
 * The development of the Polyglot project has been supported by a
 * number of funding sources, including DARPA Contract F30602-99-1-0533,
 * monitored by USAF Rome Laboratory, ONR Grants N00014-01-1-0968 and
 * N00014-09-1-0652, NSF Grants CNS-0208642, CNS-0430161, CCF-0133302,
 * and CCF-1054172, AFRL Contract FA8650-10-C-7022, an Alfred P. Sloan 
 * Research Fellowship, and an Intel Research Ph.D. Fellowship.
 *
 * See README for contributors.
 ******************************************************************************/

package polyglot.ast;

import polyglot.util.CodeWriter;
import polyglot.util.Position;
import polyglot.util.SerialVersionUID;
import polyglot.visit.PrettyPrinter;
import polyglot.visit.TypeChecker;

/**
 * The Java literal {@code null}.
 */
public class NullLit_c extends Lit_c implements NullLit {
    private static final long serialVersionUID = SerialVersionUID.generate();

//    @Deprecated
    public NullLit_c(Position pos) {
        this(pos, null);
    }

    public NullLit_c(Position pos, Ext ext) {
        super(pos, ext);
    }

    @Override
    public Node typeCheck(TypeChecker tc) {
        return type(tc.typeSystem().Null());
    }

    /** Get the value of the expression, as an object. */
    public Object objValue() {
        return null;
    }

    @Override
    public String toString() {
        return "null";
    }

    @Override
    public void prettyPrint(CodeWriter w, PrettyPrinter tr) {
        w.write("null");
    }

    @Override
    public Object constantValue(Lang lang) {
        return null;
    }

    @Override
    public Node copy(NodeFactory nf) {
        return nf.NullLit(this.position);
    }

}

==> polyglot_2.7.1.201606232226.jar: src/polyglot/ast/NullLit_c.java <==
/*******************************************************************************
 * This file is part of the Polyglot extensible compiler framework.
 *
 * Copyright (c) 2000-2012 Polyglot project group, Cornell University
 * Copyright (c) 2006-2012 IBM Corporation
 * All rights reserved.
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License v1.0 which accompanies this
 * distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This program and the accompanying materials are made available under
 * the terms of the Lesser GNU Public License v2.0 which accompanies this
 * distribution.
 *
 * The development of the Polyglot project has been supported by a
 * number of funding sources, including DARPA Contract F30602-99-1-0533,
 * monitored by USAF Rome Laboratory, ONR Grants N00014-01-1-0968 and
 * N00014-09-1-0652, NSF Grants CNS-0208642, CNS-0430161, CCF-0133302,
 * and CCF-1054172, AFRL Contract FA8650-10-C-7022, an Alfred P. Sloan
 * Research Fellowship, and an Intel Research Ph.D. Fellowship.
 *
 * See README for contributors.
 ******************************************************************************/

package polyglot.ast;

import polyglot.util.CodeWriter;
import polyglot.util.Position;
import polyglot.util.SerialVersionUID;
import polyglot.visit.PrettyPrinter;
import polyglot.visit.TypeChecker;

/**
 * The Java literal {@code null}.
 */
public class NullLit_c extends Lit_c implements NullLit {
    private static final long serialVersionUID = SerialVersionUID.generate();

//    @Deprecated
    public NullLit_c(Position pos) {
        this(pos, null);
    }

    public NullLit_c(Position pos, Ext ext) {
        super(pos, ext);
    }

    @Override
    public Node typeCheck(TypeChecker tc) {
        return type(tc.typeSystem().Null());
    }

    /** Get the value of the expression, as an object. */
    public Object objValue() {
        return null;
    }

    @Override
    public String toString() {
        return "null";
    }

    @Override
    public void prettyPrint(CodeWriter w, PrettyPrinter tr) {
        w.write("null");
    }

    @Override
    public boolean isConstant(Lang lang) {
        return false;
    }

    @Override
    public Object constantValue(Lang lang) {
        return null;
    }

    @Override
    public Node copy(NodeFactory nf) {
        return nf.NullLit(position);
    }

}
